@@ -16,8 +16,13 @@ import threading
 
 # NOTE:  Some of the unused imports might be used/imported by others.
 # Handle once test-cases are back up and running.
-from .exc import GitCommandError
-from .compat import MAXSIZE
+from .exc import InvalidGitRepositoryError
+
+from .compat import (
+    MAXSIZE,
+    defenc,
+    PY3
+)
 
 # Most of these are unused here, but are for use by git-python modules so these
 # don't see gitdb all the time. Flake of course doesn't like it.
@@ -33,13 +38,28 @@ from gitdb.util import (  # NOQA
 __all__ = ("stream_copy", "join_path", "to_native_path_windows", "to_native_path_linux",
            "join_path_native", "Stats", "IndexFileSHA1Writer", "Iterable", "IterableList",
            "BlockingLockFile", "LockFile", 'Actor', 'get_user_id', 'assure_directory_exists',
-           'RemoteProgress', 'rmtree', 'WaitGroup')
+           'RemoteProgress', 'rmtree', 'WaitGroup', 'unbare_repo')
 
 #{ Utility Methods
 
 
+def unbare_repo(func):
+    """Methods with this decorator raise InvalidGitRepositoryError if they
+    encounter a bare repository"""
+
+    def wrapper(self, *args, **kwargs):
+        if self.repo.bare:
+            raise InvalidGitRepositoryError("Method '%s' cannot operate on bare repositories" % func.__name__)
+        # END bare method
+        return func(self, *args, **kwargs)
+    # END wrapper
+    wrapper.__name__ = func.__name__
+    return wrapper
+
+
 def rmtree(path):
     """Remove the given recursively.
+
     :note: we use shutil rmtree but adjust its behaviour to see whether files that
         couldn't be deleted are read-only. Windows will not remove them in that case"""
     def onerror(func, path, exc_info):
@@ -131,15 +151,7 @@ def get_user_id():
 
 def finalize_process(proc):
     """Wait for the process (clone, fetch, pull or push) and handle its errors accordingly"""
-    try:
-        proc.wait()
-    except GitCommandError:
-        # if a push has rejected items, the command has non-zero return status
-        # a return status of 128 indicates a connection error - reraise the previous one
-        if proc.poll() == 128:
-            raise
-        pass
-    # END exception handling
+    proc.wait()
 
 #} END utilities
 
@@ -246,13 +258,18 @@ class RemoteProgress(object):
                 message = message[:-len(done_token)]
             # END end message handling
 
-            self.update(op_code, cur_count, max_count, message)
+            self.update(op_code,
+                        cur_count and float(cur_count),
+                        max_count and float(max_count),
+                        message)
         # END for each sub line
         return failed_lines
 
     def new_message_handler(self):
-        """:return: a progress handler suitable for handle_process_output(), passing lines on to this Progress
-        handler in a suitable format"""
+        """
+        :return:
+            a progress handler suitable for handle_process_output(), passing lines on to this Progress
+            handler in a suitable format"""
         def handler(line):
             return self._parse_progress_line(line.rstrip())
         # end
@@ -361,7 +378,11 @@ class Actor(object):
         for attr, evar, cvar, default in (('name', env_name, cls.conf_name, default_name),
                                           ('email', env_email, cls.conf_email, default_email)):
             try:
-                setattr(actor, attr, os.environ[evar])
+                val = os.environ[evar]
+                if not PY3:
+                    val = val.decode(defenc)
+                # end assure we don't get 'invalid strings'
+                setattr(actor, attr, val)
             except KeyError:
                 if config_reader is not None:
                     setattr(actor, attr, config_reader.get_value('user', cvar, default))
